@@ -7,6 +7,7 @@ import (
 	"os"
 	"path/filepath"
 	"runtime"
+	"strings"
 
 	log "github.com/sirupsen/logrus"
 
@@ -92,7 +93,11 @@ func (a *App) Run() (err error) {
 	}()
 	log.SetOutput(f)
 
+	log.Printf("Runtime flags: %+v", *a.Flags)
+
 	path := a.getPath()
+	path, _ = filepath.Abs(path)
+
 	ui, err = a.createUI()
 	if err != nil {
 		return
@@ -203,6 +208,7 @@ func (a *App) setNoCross(path string) error {
 			return fmt.Errorf("loading mount points: %w", err)
 		}
 		paths := device.GetNestedMountpointsPaths(path, mounts)
+		log.Printf("Ignoring mount points: %s", strings.Join(paths, ", "))
 		a.Flags.IgnoreDirs = append(a.Flags.IgnoreDirs, paths...)
 	}
 	return nil
@@ -229,18 +235,17 @@ func (a *App) runAction(ui UI, path string) error {
 			return fmt.Errorf("reading analysis: %w", err)
 		}
 	} else {
-		abspath, _ := filepath.Abs(path)
-
 		if build.RootPathPrefix != "" {
-			abspath = build.RootPathPrefix + abspath
+			path = build.RootPathPrefix + path
 		}
 
-		_, err := a.PathChecker(abspath)
+		_, err := a.PathChecker(path)
 		if err != nil {
 			return err
 		}
 
-		if err := ui.AnalyzePath(abspath, nil); err != nil {
+		log.Printf("Analyzing path: %s", path)
+		if err := ui.AnalyzePath(path, nil); err != nil {
 			return fmt.Errorf("scanning dir: %w", err)
 		}
 	}
